@@ -55,6 +55,9 @@ class MobioEnvironment:
     KAFKA_REPLICATION_FACTOR = os.environ.get('KAFKA_REPLICATION_FACTOR')
     PUBLIC_HOST = os.environ.get('PUBLIC_HOST')
 
+    YEK_REWOP = os.environ.get('YEK_REWOP', '6ca79cc8-2636-4c1e-a5cd-ba135e28a902')
+    MOBIO_TOKEN = 'Basic {}'.format(YEK_REWOP)
+
     ADM_CONFIG = '{host}/adm/v1.0/merchants/{merchant_id}/configs'
 
 
