@@ -310,7 +310,7 @@ class MobioMediaSDK(object):
 
     def get_binary_by_url(self, url):
         local_path = self.get_path_by_url(url)
-        with open(local_path, "r") as f:
+        with open(local_path, "rb") as f:
             return f.read()
 
     def get_filename_by_url(self, url):
